@@ -107,11 +107,12 @@ def lock(*args, **options):
             if not lock.acquire(options.get('blocking', False)):
                 if options.get('debug', False):
                     print(f'{lock_name} lock already acquired...return')
-                return
+
+                return options.get("locked", None)
 
             return func(*args, **kwargs)
         return __wrapper
 
     if len(args) == 1 and callable(args[0]):
         return _lock(args[0])
-    return _lock
\ No newline at end of file
+    return _lock
